@@ -20,20 +20,63 @@
 #include <gnome.h>
 #include <string.h>
 
+#include "ctree.h"
+#include "cur-proj.h"
+#include "dialog.h"
+#include "err-throw.h"
+#include "file-io.h"
 #include "gtt.h"
+#include "menucmd.h"
+#include "proj.h"
+#include "props-proj.h"
+#include "xml-gtt.h"
 
 /* XXX: this is our main window, perhaps it is a bit ugly this way and
  * should be passed around in the data fields */
 extern GtkWidget *window;
 
+static void 
+gtt_show_err (GttErrCode code)
+{
+	switch (code)
+	{
+		case GTT_NO_ERR:
+			return;
+
+		case GTT_CANT_OPEN_FILE:
+		case GTT_NOT_A_GTT_FILE:
+
+		case GTT_CANT_WRITE_CONFIG:
+		{
+			msgbox_ok(_("Warning"),
+			  _("Could not write the configuration file!"),
+			  GNOME_STOCK_BUTTON_OK,
+			  GTK_SIGNAL_FUNC(gtk_main_quit));
+			return;
+		}
+		default:
+		{
+			msgbox_ok(_("Warning"),
+			  _("Unknown error occurred"),
+			  GNOME_STOCK_BUTTON_OK,
+			  GTK_SIGNAL_FUNC(gtk_main_quit));
+			return;
+		}
+	}
+}
+
 void
 quit_app(GtkWidget *w, gpointer data)
 {
-	if (!project_list_save(NULL)) {
-		msgbox_ok(_("Warning"),
-			  _("I could not write the configuration file!"),
-			  GNOME_STOCK_BUTTON_OK,
-			  GTK_SIGNAL_FUNC(gtk_main_quit));
+	GttErrCode errcode;
+
+	gtt_err_set_code (GTT_NO_ERR);
+	save_all();
+
+	errcode = gtt_err_get_code();
+	if (GTT_NO_ERR != errcode)
+	{
+		gtt_show_err (errcode);
 		return;
 	}
 	gtk_main_quit();
@@ -47,6 +90,9 @@ about_box(GtkWidget *w, gpointer data)
         static GtkWidget *about = NULL;
         gchar *authors[] = {
                 "Eckehard Berns\n<eb@berns.i-s-o.net>",
+                "George Lebl\n<jirka@5z.com>",
+                "Linas Vepstas\n<linas@linas.org>",
+                "and dozens of bug-fixers and translators",
                 NULL
         };
 	if (about != NULL)
@@ -57,7 +103,7 @@ about_box(GtkWidget *w, gpointer data)
 	}
         about = gnome_about_new(APP_NAME,
                                 VERSION,
-                                "Copyright (C) 1997,98 Eckehard Berns",
+                                "Copyright (C) 1997,98 Eckehard Berns and others",
                                 (const gchar **)authors,
 #ifdef DEBUG
                                 __DATE__ ", " __TIME__,
@@ -78,14 +124,18 @@ static void
 project_name_desc(GtkWidget *w, GtkEntry **entries)
 {
 	char *name, *desc;
-	project *proj;
+	GttProject *proj;
 
 	if (!(name = gtk_entry_get_text(entries[0]))) return;
         if (!(desc = gtk_entry_get_text(entries[1]))) return;
 	if (!name[0]) return;
 
-	project_list_add(proj = project_new_title_desc(name, desc));
-        clist_add(proj);
+	/* New project will have the same parent as the currently
+	 * running project.  This seems like the sanest choice.
+	 */
+	proj = gtt_project_new_title_desc(name, desc);
+	gtt_project_insert_after (proj, cur_proj);
+	ctree_insert_after (proj, cur_proj);
 }
 
 static void
@@ -134,10 +184,12 @@ new_project(GtkWidget *widget, gpointer data)
         gtk_widget_show(desc);
         gtk_widget_show(table);
 
-	gtk_widget_grab_focus(title);
+	gtk_widget_grab_focus(entries[0]);
 
-	gnome_dialog_editable_enters(GNOME_DIALOG(dlg),
-				     GTK_EDITABLE(entries[0]));
+	/* enter in first entry goes to next */
+	gtk_signal_connect_object (GTK_OBJECT (entries[0]), "activate",
+				   GTK_SIGNAL_FUNC (gtk_widget_grab_focus),
+				   GTK_OBJECT (entries[1]));
 	gnome_dialog_editable_enters(GNOME_DIALOG(dlg),
 				     GTK_EDITABLE(entries[1]));
 
@@ -153,11 +205,27 @@ new_project(GtkWidget *widget, gpointer data)
 static void
 init_project_list_2(GtkWidget *widget, int button)
 {
+	GttErrCode errcode;
+        const char * xml_filepath;
+
 	GtkWidget *dlg, *t;
 	GtkBox *vbox;
 	
 	if (button != 0) return;
-	if (!project_list_load(NULL)) {
+
+	gtt_err_set_code (GTT_NO_ERR);
+
+	/* Read the data file first, and the config later. 
+	 * The config file contains stuff like the 'current project',
+	 * which is undefined until the projects are read. */
+        xml_filepath = gnome_config_get_real_path (XML_DATA_FILENAME);
+        gtt_xml_read_file (xml_filepath);
+	
+	gtt_load_config (NULL);
+	errcode = gtt_err_get_code();
+
+	if (GTT_NO_ERR != errcode) 
+	{
 		new_dialog_ok(_("Warning"), &dlg, &vbox,
 			      GNOME_STOCK_BUTTON_OK, NULL, NULL);
 		t = gtk_label_new(_("I could not read the configuration file"));
@@ -165,7 +233,7 @@ init_project_list_2(GtkWidget *widget, int button)
 		gtk_box_pack_start(vbox, t, TRUE, FALSE, 2);
 		gtk_widget_show(dlg);
 	} else {
-                setup_clist();
+                setup_ctree();
 	}
 }
 
@@ -186,13 +254,19 @@ init_project_list(GtkWidget *widget, gpointer data)
 void
 save_project_list(GtkWidget *widget, gpointer data)
 {
-	if (!project_list_save(NULL)) {
+	GttErrCode errcode;
+
+	gtt_err_set_code (GTT_NO_ERR);
+	save_all ();
+	errcode = gtt_err_get_code();
+	if (GTT_NO_ERR != errcode) 
+	{
 		GtkWidget *dlg, *t;
 		GtkBox *vbox;
 		
 		new_dialog_ok(_("Warning"), &dlg, &vbox,
 			      GNOME_STOCK_BUTTON_OK, NULL, NULL);
-		t = gtk_label_new(_("I could not write the configuration file!"));
+		t = gtk_label_new(_("Could not write the configuration file!"));
 		gtk_widget_show(t);
 		gtk_box_pack_start(vbox, t, FALSE, FALSE, 2);
 		gtk_widget_show(dlg);
@@ -200,21 +274,83 @@ save_project_list(GtkWidget *widget, gpointer data)
 	}
 }
 
+static void
+export_current_state_really (GtkWidget *widget, gpointer data)
+{
+	GtkFileSelection *fsel = data;
+	char *filename;
+
+	filename = gtk_file_selection_get_filename (fsel);
+
+	if (access (filename, F_OK) == 0) {
+		GtkWidget *w;
+		char *s;
+
+		s = g_strdup_printf (_("File %s exists, overwrite?"),
+				     filename);
+		w = gnome_question_dialog_parented (s, NULL, NULL,
+						    GTK_WINDOW (fsel));
+		g_free (s);
+
+		if (gnome_dialog_run (GNOME_DIALOG (w)) != 0)
+			return;
+	}
+
+	if ( ! project_list_export (filename)) {
+		GtkWidget *w = gnome_error_dialog (_("File cannot be written"));
+		gnome_dialog_set_parent (GNOME_DIALOG (w), GTK_WINDOW (fsel));
+		return;
+	}
+
+	gtk_widget_destroy (GTK_WIDGET (fsel));
+}
+
+void
+export_current_state (GtkWidget *widget, gpointer data)
+{
+	static GtkWidget *dialog = NULL;
+	GtkFileSelection *fsel;
+
+	if (dialog != NULL) {
+		gtk_widget_show_now (dialog);
+		gdk_window_raise (dialog->window);
+		return;
+	}
+
+	dialog = gtk_file_selection_new (_("Export Current State"));
+	gtk_window_set_transient_for (GTK_WINDOW (dialog),
+				      GTK_WINDOW (window));
+	fsel = GTK_FILE_SELECTION (dialog);
+
+	gtk_signal_connect (GTK_OBJECT (dialog), "destroy",
+			    GTK_SIGNAL_FUNC (gtk_widget_destroyed),
+			    &dialog);
+
+	gtk_signal_connect (GTK_OBJECT (fsel->ok_button), "clicked",
+			    GTK_SIGNAL_FUNC (export_current_state_really),
+			    fsel);
+
+	gtk_signal_connect_object (GTK_OBJECT (fsel->cancel_button), "clicked",
+				   GTK_SIGNAL_FUNC (gtk_widget_destroy),
+				   GTK_OBJECT (fsel));
+
+	gtk_widget_show (dialog);
+}
 
 
-project *cutted_project = NULL;
+GttProject *cutted_project = NULL;
 
 void
 cut_project(GtkWidget *w, gpointer data)
 {
 	if (!cur_proj) return;
 	if (cutted_project)
-		project_destroy(cutted_project);
+		gtt_project_destroy(cutted_project);
 	cutted_project = cur_proj;
 	prop_dialog_set_project(NULL);
-	project_list_remove(cur_proj);
+	gtt_project_remove(cur_proj);
 	cur_proj_set(NULL);
-        clist_remove(cutted_project);
+        ctree_remove(cutted_project);
 }
 
 
@@ -222,19 +358,23 @@ cut_project(GtkWidget *w, gpointer data)
 void
 paste_project(GtkWidget *w, gpointer data)
 {
-	int pos;
-	project *p;
+	GttProject *p;
 	
 	if (!cutted_project) return;
-	p = project_dup(cutted_project);
+	p = cutted_project;
+
+	/* if we paste a second time, we better paste a copy ... */
+	cutted_project = gtt_project_dup(cutted_project);
+
+	/* insert before the current proj */
+	gtt_project_insert_before (p, cur_proj);
+
 	if (!cur_proj) {
-                clist_add(p);
-		project_list_add(p);
+		/* top-level insert */
+                ctree_add(p, NULL);
 		return;
 	}
-        pos = cur_proj->row;
-	project_list_insert(p, pos);
-        clist_insert(p, pos);
+        ctree_insert_before(p, cur_proj);
 }
 
 
@@ -244,8 +384,8 @@ copy_project(GtkWidget *w, gpointer data)
 {
 	if (!cur_proj) return;
 	if (cutted_project)
-		project_destroy(cutted_project);
-	cutted_project = project_dup(cur_proj);
+		gtt_project_destroy(cutted_project);
+	cutted_project = gtt_project_dup(cur_proj);
 	menu_set_states(); /* to enable paste */
 }
 
@@ -277,10 +417,10 @@ void
 menu_toggle_timer(GtkWidget *w, gpointer data)
 {
 	/* if (GTK_CHECK_MENU_ITEM(menus_get_toggle_timer())->active) { */
-	if (main_timer == 0) {
-		start_timer();
-	} else {
+	if (timer_is_running()) {
 		stop_timer();
+	} else {
+		start_timer();
 	}
 	menu_set_states();
 }
@@ -298,7 +438,7 @@ void
 menu_properties(GtkWidget *w, gpointer data)
 {
 	if (cur_proj) {
-		prop_dialog(cur_proj);
+		prop_dialog_show(cur_proj);
 	}
 }
 
@@ -309,7 +449,7 @@ menu_clear_daily_counter(GtkWidget *w, gpointer data)
 {
 	g_return_if_fail(cur_proj != NULL);
 
-	cur_proj->day_secs = 0;
-        clist_update_label(cur_proj);
+	gtt_clear_daily_counter (cur_proj);
+        ctree_update_label(cur_proj);
 }
 
