@@ -20,7 +20,11 @@
 #include <gnome.h>
 #include <string.h>
 
+#include "cur-proj.h"
 #include "gtt.h"
+#include "journal.h"
+#include "menucmd.h"
+#include "toolbar.h"
 
 
 static GnomeUIInfo menu_main_file[] = {
@@ -64,7 +68,12 @@ static GnomeUIInfo menu_main_edit[] = {
 			       menu_clear_daily_counter,
 			       GNOME_STOCK_MENU_BLANK),
 	GNOMEUIINFO_SEPARATOR,
-#define MENU_EDIT_PROP_POS 6
+#define MENU_EDIT_JNL_POS 6
+	GNOMEUIINFO_ITEM_STOCK(N_("_Journal..."), NULL,
+			       edit_journal,
+			       GNOME_STOCK_MENU_BLANK),
+	GNOMEUIINFO_SEPARATOR,
+#define MENU_EDIT_PROP_POS 8
 	GNOMEUIINFO_MENU_PROPERTIES_ITEM(menu_properties,NULL),
 	GNOMEUIINFO_END
 };
@@ -167,13 +176,13 @@ menu_set_states(void)
 	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_TOGGLE_POS].widget,
 				 1);
 	mi = GTK_CHECK_MENU_ITEM(menu_main_timer[MENU_TIMER_TOGGLE_POS].widget);
-	mi->active = (main_timer != 0);
+	mi->active = timer_is_running();
 	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_TOGGLE_POS].widget,
 				 (cur_proj != NULL));
 	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_START_POS].widget,
-				 (main_timer == 0) && (cur_proj));
+				 (FALSE == timer_is_running()) && (cur_proj));
 	gtk_widget_set_sensitive(menu_main_timer[MENU_TIMER_STOP_POS].widget,
-				 (main_timer != 0) && (cur_proj));
+				 (timer_is_running()) && (cur_proj));
 	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_CUT_POS].widget,
 				 (cur_proj) ? 1 : 0);
 	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_COPY_POS].widget,
@@ -182,6 +191,8 @@ menu_set_states(void)
 				 (cutted_project) ? 1 : 0);
 	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_CDC_POS].widget,
 				 (cur_proj) ? 1 : 0);
+	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_JNL_POS].widget,
+				 (cur_proj) ? 1 : 0);
 	gtk_widget_set_sensitive(menu_main_edit[MENU_EDIT_PROP_POS].widget,
 				 (cur_proj) ? 1 : 0);
 
