@@ -21,8 +21,11 @@
 #include <libgnome/gnome-help.h>
 #include <string.h>
 
+#include "cur-proj.h"
 #include "gtt.h"
-
+#include "journal.h"
+#include "menucmd.h"
+#include "toolbar.h"
 
 
 
@@ -34,6 +37,7 @@ struct _MyToolbar {
         GtkTooltips *tt;
         GtkWidget *cut, *copy, *paste; /* to make them sensible
                                           as needed */
+        GtkWidget *journal_w;
         GtkWidget *prop_w;
 	GtkWidget *timer_w;
 	GnomeStock *timer;
@@ -73,7 +77,7 @@ add_toggle_button(GtkToolbar *tbar, char *text, char *tt_text,
 void
 toolbar_set_states(void)
 {
-        extern project *cutted_project;
+        extern GttProject *cutted_project;
 	GtkToolbarStyle tb_style;
 
         g_return_if_fail(mytbar != NULL);
@@ -97,7 +101,7 @@ toolbar_set_states(void)
                 gtk_widget_set_sensitive(mytbar->prop_w, (cur_proj != NULL));
         if (mytbar->timer)
 		gnome_stock_set_icon(mytbar->timer,
-				     (main_timer != 0) ?
+				     (timer_is_running()) ?
 				     GNOME_STOCK_PIXMAP_TIMER_STOP :
 				     GNOME_STOCK_PIXMAP_TIMER);
 	if (mytbar->timer_w)
@@ -139,7 +143,7 @@ build_toolbar(void)
         if (config_show_tb_new) {
                 /* Note to translators: just skip the `[GTT]' */
                 add_stock_button(mytbar->tbar, gtt_gettext(_("[GTT]New")),
-                                 _("New Project..."),
+                                 _("Create a New Project..."),
                                  GNOME_STOCK_PIXMAP_NEW,
                                  (GtkSignalFunc)new_project);
                 gtk_toolbar_append_space(mytbar->tbar);
@@ -170,19 +174,29 @@ build_toolbar(void)
                                                  (GtkSignalFunc)paste_project);
                 gtk_toolbar_append_space(mytbar->tbar);
         }
+        if (config_show_tb_journal) {
+                mytbar->journal_w = add_stock_button(mytbar->tbar, 
+                                 _("Journal"),
+                                 _("View and Edit Timestamp Logs"),
+                                 GNOME_STOCK_PIXMAP_BOOK_OPEN,
+                                 (GtkSignalFunc)edit_journal);
+        }
         if (config_show_tb_prop)
                 mytbar->prop_w = add_stock_button(mytbar->tbar, _("Props"),
-                                                  _("Edit Properties..."),
-                                                  GNOME_STOCK_PIXMAP_PROPERTIES,
-						  (GtkSignalFunc)menu_properties);
+                                  _("Edit Project Properties..."),
+                                  GNOME_STOCK_PIXMAP_PROPERTIES,
+				  (GtkSignalFunc)menu_properties);
         if (config_show_tb_timer)
 		mytbar->timer = add_toggle_button(mytbar->tbar, _("Timer"),
-						  _("Start/Stop Timer"),
-						  GNOME_STOCK_PIXMAP_TIMER,
-						  (GtkSignalFunc)menu_toggle_timer,
-						  &(mytbar->timer_w));
-        if (((config_show_tb_timer) || (config_show_tb_prop)) &&
-            ((config_show_tb_pref) || (config_show_tb_help) ||
+			          _("Start/Stop Timer"),
+				  GNOME_STOCK_PIXMAP_TIMER,
+				  (GtkSignalFunc)menu_toggle_timer,
+				  &(mytbar->timer_w));
+        if (((config_show_tb_timer)    || 
+	     (config_show_tb_journal)  ||    
+	     (config_show_tb_prop)     ) &&
+            ((config_show_tb_pref) || 
+	     (config_show_tb_help) ||
              (config_show_tb_exit)))
                 gtk_toolbar_append_space(mytbar->tbar);
         if (config_show_tb_pref)
@@ -191,7 +205,8 @@ build_toolbar(void)
 				 GNOME_STOCK_PIXMAP_PREFERENCES,
 				 (GtkSignalFunc)menu_options);
         if (config_show_tb_help) {
-		add_stock_button(mytbar->tbar, _("Manual"), _("Manual..."),
+		add_stock_button(mytbar->tbar, _("Manual"), 
+                                 _("User's Guide and Manual"),
 				 GNOME_STOCK_PIXMAP_HELP,
 				 (GtkSignalFunc)toolbar_help);
         }
